@@ -1,10 +1,8 @@
 // This file is part of https://github.com/SpringQL/SpringQL which is licensed under MIT OR Apache-2.0. See file LICENSE-MIT or LICENSE-APACHE for full license details.
 
-use serde::{Deserialize, Serialize};
-
 use crate::pipeline::name::SinkWriterName;
 
-#[derive(Clone, Eq, PartialEq, Debug, Serialize, Deserialize)]
+#[derive(Clone, Eq, PartialEq, Debug)]
 pub(crate) enum SinkWriterType {
     Net,
     InMemoryQueue,
